@@ -7,7 +7,7 @@ from tracker_master.app_master.message_queue import MessageQueueWorker
 from tracker_master.model.app_model import Message
 
 
-def parse(message_string):
+def parse(message_string) -> Message:
     return Message(hw_id=int(message_string[0:8]),
                    _type=int(message_string[8]),
                    charge=float(message_string[9:13]))
@@ -31,6 +31,8 @@ class SlaveReaderThread(MessageQueueWorker):
                     try:
                         msg = ser.readline().decode().strip()
                         self.port_logger.info(msg)
-                        self.put_message(parse(msg))
+                        message = parse(msg)
+                        message.time = util.unix_time()
+                        self.put_message(message)
                     except Exception as ex:
-                        self.logger.error(ex)
+                        self.logger.error('Parse message error:' + ex)
