@@ -24,6 +24,10 @@ def com_port_log_file():
     return CONFIG[PROFILE]['com_port_log_file']
 
 
+def missed_data_storage_folder():
+    return CONFIG[PROFILE]['missed_data_storage_folder']
+
+
 def zbx_user():
     return CONFIG[PROFILE]['zabbix']['user']
 
